/*
BME280 I2C Test.ino

This code shows how to record data from the BME280 environmental sensor
using I2C interface. This file is an example file, part of the Arduino
BME280 library.

GNU General Public License

Written: Dec 30 2015.
Last Updated: Oct 07 2017.

Connecting the AE-BME280 (BME280 Sensor Board):
AE-BME280           ->  ES920LR3 on AVR64DB32 Board
-----------------------------
VDD                 ->  VDD (Set the short jumper on the back of the board to 3.3V)
GND (Ground)        ->  GND
CSB                 ->  Open (short J3)
SDI (SDA)           ->  PA2
SDO (I2C address)   ->  GND (set the I2C address to 0x76)
SCK (SCL)           ->  PA3
                        Short J1, J2, and J3 for I2C.

 */

#include <BME280I2C.h>
#include <Wire.h>
#include "LoRa.h"

#define SERIAL_BAUD 115200

BME280I2C bme;    // Default : forced mode, standby time = 1000 ms
                  // Oversampling = pressure ×1, temperature ×1, humidity ×1, filter off,

float temp = 0.0;
float hum = 0.0;
float pres = 0.0;
float pressure = 0.0;

//////////////////////////////////////////////////////////////////
void setup(){
  Serial.begin(SERIAL_BAUD);
  while(!Serial) {} // Wait
  Wire.end();
  Wire.begin();
  while(!bme.begin()){
    Serial.println("Could not find BME280 sensor!");
    delay(1000);
  }

  switch(bme.chipModel()){
     case BME280::ChipModel_BME280:
       Serial.println("Found BME280 sensor! Success.");
       break;
     case BME280::ChipModel_BMP280:
       Serial.println("Found BMP280 sensor! No Humidity available.");
       break;
     default:
       Serial.println("Found UNKNOWN sensor! Error!");
  }
  LoRaInit();
}

//////////////////////////////////////////////////////////////////
void loop(){
   printBME280Data(&Serial);
   LoRaCommand("MC"+String(temp)+" "+String(hum)+((pressure < 1000)? "  ":" ")+String(pressure));
   delay(5000);
}

//////////////////////////////////////////////////////////////////
void printBME280Data(Stream* client){

   BME280::TempUnit tempUnit(BME280::TempUnit_Celsius);
   BME280::PresUnit presUnit(BME280::PresUnit_Pa);

   bme.read(pres, temp, hum, tempUnit, presUnit);
   pressure = pres / 100;

   client->print("Temp: ");
   client->print(temp);
   client->print("°"+ String(tempUnit == BME280::TempUnit_Celsius ? 'C' :'F'));
   client->print("\t\tHumidity: ");
   client->print(hum);
   client->print("% RH");
   client->print("\t\tPressure: ");
   client->print(pres);
   client->println("Pa");

}
